elephant.unitary\_event\_analysis.jointJ\_window\_analysis
==========================================================

.. currentmodule:: elephant.unitary_event_analysis

.. autofunction:: jointJ_window_analysis